@@ -20,9 +20,9 @@
 #include "DiscoverMainWindow.h"
 #include "PaginateModel.h"
 #include "SystemFonts.h"
-#include "IconColors.h"
 #include "UnityLauncher.h"
 #include "FeaturedModel.h"
+#include "CachedNetworkAccessManager.h"
 
 // Qt includes
 #include <QAction>
@@ -92,10 +92,9 @@ DiscoverMainWindow::DiscoverMainWindow(CompactMode mode)
     KDeclarative::KDeclarative kdeclarative;
     kdeclarative.setDeclarativeEngine(m_engine);
     kdeclarative.setupBindings();
-    
+
     qmlRegisterType<UnityLauncher>("org.kde.discover.app", 1, 0, "UnityLauncher");
     qmlRegisterType<PaginateModel>("org.kde.discover.app", 1, 0, "PaginateModel");
-    qmlRegisterType<IconColors>("org.kde.discover.app", 1, 0, "IconColors");
     qmlRegisterType<KConcatenateRowsProxyModel>("org.kde.discover.app", 1, 0, "KConcatenateRowsProxyModel");
     qmlRegisterType<FeaturedModel>("org.kde.discover.app", 1, 0, "FeaturedModel");
     qmlRegisterType<QSortFilterProxyModel>("org.kde.discover.app", 1, 0, "QSortFilterProxyModel");
@@ -108,8 +107,10 @@ DiscoverMainWindow::DiscoverMainWindow(CompactMode mode)
     qmlRegisterType<QAction>();
     qmlRegisterUncreatableType<DiscoverMainWindow>("org.kde.discover.app", 1, 0, "DiscoverMainWindow", QStringLiteral("don't do that"));
     setupActions();
-    
+
     //Here we set up a cache for the screenshots
+    CachedNetworkAccessManagerFactory *networkAccessManagerFactory = new CachedNetworkAccessManagerFactory;
+    m_engine->setNetworkAccessManagerFactory(networkAccessManagerFactory);
     m_engine->rootContext()->setContextProperty(QStringLiteral("app"), this);
 
     connect(m_engine, &QQmlApplicationEngine::objectCreated, this, &DiscoverMainWindow::integrateObject);
@@ -144,7 +145,7 @@ void DiscoverMainWindow::openMode(const QString& _mode)
 {
     if(!modes().contains(_mode))
         qWarning() << "unknown mode" << _mode;
-    
+
     QString mode = _mode;
     mode[0] = mode[0].toUpper();
 
